@@ -20,7 +20,7 @@ rather to the pages it generates. */
 
 $sovix__page__copyright="Copyright (C) 2008 David Englund.
 Permission is granted to copy, distribute and/or modify this document
-under the terms of the GNU Free Documentation License, Version 1.2 or any
+under the terms of the GNU Free Documentation License, Version 1.3 or any
 later version published by the Free Software Foundation; with no Invariant
 Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
 $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
@@ -337,12 +337,13 @@ You can find the settings in dotsovix/public.inc.
 </p>
 
 <ul>
-<li>Screen mode: <span style="color:#0000BB">$sovix__screen_mode</span>. This is set to 'normal' by default which means that these user interfaces are configured, they are also visible by default:
+  <li>Screen mode: <span style="color:#0000BB">$sovix__screen_mode</span>. This is set to &ldquo;normal&rdquo; by default which means that these user interfaces are configured, they are also visible by default:
     <ul>
       <li>&ldquo;Window&rdquo; border: <span style="color:#0000BB">$sovix__window_border_mode</span></li>
       <li>Menu bar: <span style="color:#0000BB">$sovix__menu_bar_mode</span></li>
       <li>Tool bar: <span style="color:#0000BB">$sovix__tool_bar_mode</span></li>
       <li>Top select menu: <span style="color:#0000BB">$sovix__select_menu_header_mode</span></li>
+      <li>Side pane: <span style="color:#0000BB">$sovix__menu__side_pane_mode</span></li>
       <li>Bottom select menu: <span style="color:#0000BB">$sovix__select_menu_footer_mode</span></li>
       <li>Command line: <span style="color:#0000BB">$sovix__command_line_mode</span></li>
     </ul>
