@@ -19,8 +19,10 @@ The text in $sovix__page__copyright doesn't apply to this file, but
 rather to the pages it generates. */
 
 $sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
-This entire article is distributed under the GNU Free Documentation
-License, Version 1.2 or any later version.";
+Permission is granted to copy, distribute and/or modify this document
+under the terms of the GNU Free Documentation License, Version 1.3 or any
+later version published by the Free Software Foundation; with no Invariant
+Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
 if (isset($_GET['sovix__directory__src'])) {
   $sovix__directory__src=$_GET['sovix__directory__src'];
   $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
